magneticalc.QtWidgets2.QIconLabel.QIconLabel

# ``magneticalc`.`QtWidgets2`.`QIconLabel`.`QIconLabel``

class documentation

`class QIconLabel(QHBoxLayout):`

Constructor: `QIconLabel(text, icon, color, text_color, ...)`

View In Hierarchy

QIconLabel class.

Method | `__init__` | Initializes the icon label.
Class Variable | `HorizontalSpacing` | Undocumented

def __init__(self, text: `str`, icon: `str`, color: `str | None` = None, text_color: `str | None` = None, icon_color: `str | None` = None, icon_size: `QSize` = QSize(16, 16), font: `QFont | None` = None, expand: `bool` = True):

Initializes the icon label.

Parameters
text: `str` | Label text
icon: `str` | QtAwesome icon ID
color: `str | None` | Text and icon color (optional)
text_color: `str | None` | Text color (optional, overrides color)
icon_color: `str | None` | Icon color (optional, overrides color)
icon_size: `QSize` | Icon size
font: `QFont | None` | QFont
expand: `bool` | Enable to expand label

HorizontalSpacing: `int` =

Undocumented